@@ -20,30 +20,48 @@ from . import __version__
 
 STDIN_PROMPT = '__stdin_prompt>'
 STDIN_PROMPT_REGEX = re.compile(r'\A.+?%s|debug> ' % STDIN_PROMPT)
+HELP_LINKS = [
+    {
+        'text': "GNU Octave",
+        'url': "https://www.gnu.org/software/octave/support.html",
+    },
+    {
+        'text': "Octave Kernel",
+        'url': "https://github.com/Calysto/octave_kernel",
+    },
+
+] + MetaKernel.help_links
 
 
 class OctaveKernel(ProcessMetaKernel):
     implementation = 'Octave Kernel'
     implementation_version = __version__,
     language = 'octave'
-    language_version = __version__,
-    banner = "Octave Kernel",
-    language_info = {
-        'mimetype': 'text/x-octave',
-        'name': 'octave',
-        'file_extension': '.m',
-        "version": __version__,
-        'help_links': MetaKernel.help_links,
-    }
+    help_links = HELP_LINKS
 
-    _banner = None
     _octave_engine = None
+    _language_version = None
+
+    @property
+    def language_version(self):
+        if self._language_version:
+            return self._language_version
+        ver = self.octave_engine.eval('version', silent=True)
+        ver = self._language_version = ver.split()[-1]
+        return ver
+
+    @property
+    def language_info(self):
+        return {'mimetype': 'text/x-octave',
+                'name': 'octave',
+                'file_extension': '.m',
+                'version': self.language_version,
+                'help_links': HELP_LINKS}
 
     @property
     def banner(self):
-        if self._banner is None:
-            self._banner = self.octave_engine.eval('info', silent=True)
-        return self._banner
+        msg = 'Octave Kernel v%s running GNU Octave v%s'
+        return msg % (__version__, self.language_version)
 
     @property
     def octave_engine(self):
@@ -59,6 +77,8 @@ class OctaveKernel(ProcessMetaKernel):
     def makeWrapper(self):
         """Start an Octave process and return a :class:`REPLWrapper` object.
         """
+        if self.wrapper:
+            self._octave_engine = None
         return self.octave_engine.repl
 
     def do_execute_direct(self, code, silent=False):
@@ -68,9 +88,8 @@ class OctaveKernel(ProcessMetaKernel):
         val = ProcessMetaKernel.do_execute_direct(self, code, silent=silent)
         if not silent:
             plot_dir = self.octave_engine.make_figures()
-            for image in self.octave_engine.extract_figures(plot_dir):
+            for image in self.octave_engine.extract_figures(plot_dir, True):
                 self.Display(image)
-            shutil.rmtree(plot_dir, True)
         return val
 
     def get_kernel_help_on(self, info, level=0, none_on_fail=False):
@@ -207,8 +226,13 @@ class OctaveEngine(object):
         name = settings['name']
         plot_dir = plot_dir or tempfile.mkdtemp()
         plot_dir = plot_dir.replace(os.path.sep, '/')
-        make_figs = '_make_figures("%s", "%s", "%s", %d, %d, %d)'
-        make_figs = make_figs % (plot_dir, fmt, name, wid, hgt, res)
+
+        # Do not overwrite any existing plot files.
+        spec = os.path.join(plot_dir, '%s*' % name)
+        start = len(glob.glob(spec))
+
+        make_figs = '_make_figures("%s", "%s", "%s", %d, %d, %d, %d)'
+        make_figs = make_figs % (plot_dir, fmt, name, wid, hgt, res, start)
         resp = self.eval(make_figs, silent=True)
         if resp and 'error:' in resp:
             if self.error_handler:
@@ -217,17 +241,19 @@ class OctaveEngine(object):
                 raise Exception(resp)
         return plot_dir
 
-    def extract_figures(self, plot_dir):
+    def extract_figures(self, plot_dir, remove=False):
         """Get a list of IPython Image objects for the created figures.
 
         Parameters
         ----------
         plot_dir: str
             The directory in which to create the plots.
+        remove: bool, optional.
+            Whether to remove the plot directory after saving.
         """
         images = []
-        path = os.path.join(plot_dir, '%s*' % self.plot_settings['name'])
-        for fname in reversed(glob.glob(path)):
+        spec = os.path.join(plot_dir, '%s*' % self.plot_settings['name'])
+        for fname in reversed(glob.glob(spec)):
             filename = os.path.join(plot_dir, fname)
             try:
                 if fname.lower().endswith('.svg'):
@@ -240,6 +266,8 @@ class OctaveEngine(object):
                     self.error_handler(e)
                 else:
                     raise e
+        if remove:
+            shutil.rmtree(plot_dir, True)
         return images
 
     def _startup(self, plot_settings):
@@ -323,9 +351,11 @@ class OctaveEngine(object):
 
     def _interrupt(self, silent=False):
         if (os.name == 'nt'):
-            if self.logger:
-                msg = 'Cannot interrupt Octave kernel on Windows'
-                self.logger.warning(msg)
+            msg = '** Warning: Cannot interrupt Octave on Windows'
+            if self.stream_handler:
+                self.stream_handler(msg)
+            elif self.logger:
+                self.logger.warn(msg)
             return self._interrupt_expect(silent)
         return REPLWrapper.interrupt(self.repl)
 
